@@ -1,13 +1,10 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2007-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: peer-msgs.c 14114 2013-07-09 17:05:32Z jordan $
+ * $Id: peer-msgs.c 14266 2014-04-27 23:10:01Z jordan $
  */
 
 #include <assert.h>
@@ -223,7 +220,7 @@ struct tr_peerMsgs
 
   tr_torrent *           torrent;
 
-  tr_peer_callback      * callback;
+  tr_peer_callback        callback;
   void                  * callbackData;
 
   struct evbuffer *      outMessages; /* all the non-piece messages */
@@ -333,7 +330,7 @@ pokeBatchPeriod (tr_peerMsgs * msgs, int interval)
 static void
 dbgOutMessageLen (tr_peerMsgs * msgs)
 {
-  dbgmsg (msgs, "outMessage size is now %zu", evbuffer_get_length (msgs->outMessages));
+  dbgmsg (msgs, "outMessage size is now %"TR_PRIuSIZE, evbuffer_get_length (msgs->outMessages));
 }
 
 static void
@@ -479,7 +476,7 @@ static void
 publish (tr_peerMsgs * msgs, tr_peer_event * e)
 {
   if (msgs->callback != NULL)
-    msgs->callback (&msgs->peer, e, msgs->callbackData);
+    (*msgs->callback) (&msgs->peer, e, msgs->callbackData);
 }
 
 static void
@@ -903,7 +900,7 @@ void
 tr_peerMsgsCancel (tr_peerMsgs * msgs, tr_block_index_t block)
 {
     struct peer_request req;
-/*fprintf (stderr, "SENDING CANCEL MESSAGE FOR BLOCK %zu\n\t\tFROM PEER %p ------------------------------------\n", (size_t)block, msgs->peer);*/
+/*fprintf (stderr, "SENDING CANCEL MESSAGE FOR BLOCK %"TR_PRIuSIZE"\n\t\tFROM PEER %p ------------------------------------\n", (size_t)block, msgs->peer);*/
     blockToReq (msgs->torrent, block, &req);
     protocolSendCancel (msgs, &req);
 }
@@ -1291,7 +1288,7 @@ readBtId (tr_peerMsgs * msgs, struct evbuffer * inbuf, size_t inlen)
 
     tr_peerIoReadUint8 (msgs->io, inbuf, &id);
     msgs->incoming.id = id;
-    dbgmsg (msgs, "msgs->incoming.id is now %d; msgs->incoming.length is %zu", id, (size_t)msgs->incoming.length);
+    dbgmsg (msgs, "msgs->incoming.id is now %d; msgs->incoming.length is %"TR_PRIuSIZE, id, (size_t)msgs->incoming.length);
 
     if (id == BT_PIECE)
     {
@@ -1339,10 +1336,10 @@ peerMadeRequest (tr_peerMsgs * msgs, const struct peer_request * req)
 {
     const bool fext = tr_peerIoSupportsFEXT (msgs->io);
     const int reqIsValid = requestIsValid (msgs, req);
-    const int clientHasPiece = reqIsValid && tr_cpPieceIsComplete (&msgs->torrent->completion, req->index);
+    const int clientHasPiece = reqIsValid && tr_torrentPieceIsComplete (msgs->torrent, req->index);
     const int peerIsChoked = msgs->peer_is_choked;
 
-    int allow = false;
+    bool allow = false;
 
     if (!reqIsValid)
         dbgmsg (msgs, "rejecting an invalid request.");
@@ -1454,7 +1451,7 @@ readBtPiece (tr_peerMsgs      * msgs,
 
         fireClientGotPieceData (msgs, n);
         *setme_piece_bytes_read += n;
-        dbgmsg (msgs, "got %zu bytes for block %u:%u->%u ... %d remain",
+        dbgmsg (msgs, "got %"TR_PRIuSIZE" bytes for block %u:%u->%u ... %d remain",
                n, req->index, req->offset, req->length,
              (int)(req->length - evbuffer_get_length (block_buffer)));
         if (evbuffer_get_length (block_buffer) < req->length)
@@ -1486,7 +1483,7 @@ readBtMessage (tr_peerMsgs * msgs, struct evbuffer * inbuf, size_t inlen)
 
     --msglen; /* id length */
 
-    dbgmsg (msgs, "got BT id %d, len %d, buffer size is %zu", (int)id, (int)msglen, inlen);
+    dbgmsg (msgs, "got BT id %d, len %d, buffer size is %"TR_PRIuSIZE, (int)id, (int)msglen, inlen);
 
     if (inlen < msglen)
         return READ_LATER;
@@ -1708,7 +1705,7 @@ clientGotBlock (tr_peerMsgs                * msgs,
         dbgmsg (msgs, "we didn't ask for this message...");
         return 0;
     }
-    if (tr_cpPieceIsComplete (&msgs->torrent->completion, req->index)) {
+    if (tr_torrentPieceIsComplete (msgs->torrent, req->index)) {
         dbgmsg (msgs, "we did ask for this message, but the piece is already complete...");
         return 0;
     }
@@ -1747,7 +1744,7 @@ canRead (tr_peerIo * io, void * vmsgs, size_t * piece)
     struct evbuffer * in = tr_peerIoGetReadBuffer (io);
     const size_t      inlen = evbuffer_get_length (in);
 
-    dbgmsg (msgs, "canRead: inlen is %zu, msgs->state is %d", inlen, msgs->state);
+    dbgmsg (msgs, "canRead: inlen is %"TR_PRIuSIZE", msgs->state is %d", inlen, msgs->state);
 
     if (!inlen)
     {
@@ -1915,14 +1912,14 @@ fillOutputBuffer (tr_peerMsgs * msgs, time_t now)
 
     if (haveMessages && !msgs->outMessagesBatchedAt) /* fresh batch */
     {
-        dbgmsg (msgs, "started an outMessages batch (length is %zu)", evbuffer_get_length (msgs->outMessages));
+        dbgmsg (msgs, "started an outMessages batch (length is %"TR_PRIuSIZE")", evbuffer_get_length (msgs->outMessages));
         msgs->outMessagesBatchedAt = now;
     }
     else if (haveMessages && ((now - msgs->outMessagesBatchedAt) >= msgs->outMessagesBatchPeriod))
     {
         const size_t len = evbuffer_get_length (msgs->outMessages);
         /* flush the protocol messages */
-        dbgmsg (msgs, "flushing outMessages... to %p (length is %zu)", msgs->io, len);
+        dbgmsg (msgs, "flushing outMessages... to %p (length is %"TR_PRIuSIZE")", (void*)msgs->io, len);
         tr_peerIoWriteBuf (msgs->io, msgs->outMessages, false);
         msgs->clientSentAnythingAt = now;
         msgs->outMessagesBatchedAt = 0;
@@ -2006,7 +2003,7 @@ fillOutputBuffer (tr_peerMsgs * msgs, time_t now)
         --msgs->prefetchCount;
 
         if (requestIsValid (msgs, &req)
-            && tr_cpPieceIsComplete (&msgs->torrent->completion, req.index))
+            && tr_torrentPieceIsComplete (msgs->torrent, req.index))
         {
             int err;
             const uint32_t msglen = 4 + 1 + 4 + 4 + req.length;
@@ -2029,7 +2026,7 @@ fillOutputBuffer (tr_peerMsgs * msgs, time_t now)
             /* check the piece if it needs checking... */
             if (!err && tr_torrentPieceNeedsCheck (msgs->torrent, req.index))
                 if ((err = !tr_torrentCheckPiece (msgs->torrent, req.index)))
-                    tr_torrentSetLocalError (msgs->torrent, _("Please Verify Local Data! Piece #%zu is corrupt."), (size_t)req.index);
+                    tr_torrentSetLocalError (msgs->torrent, _("Please Verify Local Data! Piece #%"TR_PRIuSIZE" is corrupt."), (size_t)req.index);
 
             if (err)
             {
@@ -2126,11 +2123,11 @@ sendBitfield (tr_peerMsgs * msgs)
 
     assert (tr_torrentHasMetadata (msgs->torrent));
 
-    bytes = tr_cpCreatePieceBitfield (&msgs->torrent->completion, &byte_count);
+    bytes = tr_torrentCreatePieceBitfield (msgs->torrent, &byte_count);
     evbuffer_add_uint32 (out, sizeof (uint8_t) + byte_count);
     evbuffer_add_uint8 (out, BT_BITFIELD);
     evbuffer_add     (out, bytes, byte_count);
-    dbgmsg (msgs, "sending bitfield... outMessage size is now %zu", evbuffer_get_length (out));
+    dbgmsg (msgs, "sending bitfield... outMessage size is now %"TR_PRIuSIZE, evbuffer_get_length (out));
     pokeBatchPeriod (msgs, IMMEDIATE_PRIORITY_INTERVAL_SECS);
 
     tr_free (bytes);
@@ -2141,15 +2138,15 @@ tellPeerWhatWeHave (tr_peerMsgs * msgs)
 {
     const bool fext = tr_peerIoSupportsFEXT (msgs->io);
 
-    if (fext && tr_cpHasAll (&msgs->torrent->completion))
+    if (fext && tr_torrentHasAll (msgs->torrent))
     {
         protocolSendHaveAll (msgs);
     }
-    else if (fext && tr_cpHasNone (&msgs->torrent->completion))
+    else if (fext && tr_torrentHasNone (msgs->torrent))
     {
         protocolSendHaveNone (msgs);
     }
-    else if (!tr_cpHasNone (&msgs->torrent->completion))
+    else if (!tr_torrentHasNone (msgs->torrent))
     {
         sendBitfield (msgs);
     }
@@ -2425,7 +2422,7 @@ sendPex (tr_peerMsgs * msgs)
             evbuffer_add_uint8 (out, msgs->ut_pex_id);
             evbuffer_add_buffer (out, payload);
             pokeBatchPeriod (msgs, HIGH_PRIORITY_INTERVAL_SECS);
-            dbgmsg (msgs, "sending a pex message; outMessage size is now %zu", evbuffer_get_length (out));
+            dbgmsg (msgs, "sending a pex message; outMessage size is now %"TR_PRIuSIZE, evbuffer_get_length (out));
             dbgOutMessageLen (msgs);
 
             evbuffer_free (payload);
@@ -2445,7 +2442,7 @@ sendPex (tr_peerMsgs * msgs)
 }
 
 static void
-pexPulse (int foo UNUSED, short bar UNUSED, void * vmsgs)
+pexPulse (evutil_socket_t foo UNUSED, short bar UNUSED, void * vmsgs)
 {
     struct tr_peerMsgs * msgs = vmsgs;
 
@@ -2605,7 +2602,7 @@ tr_peerMsgsCast (void * vm)
 tr_peerMsgs *
 tr_peerMsgsNew (struct tr_torrent    * torrent,
                 struct tr_peerIo     * io,
-                tr_peer_callback     * callback,
+                tr_peer_callback       callback,
                 void                 * callbackData)
 {
   tr_peerMsgs * m;
